function [faces, weights] = computeCumFaces(Xtrain, XtrainNormalized, avgFace, index, U, numPC)
% [faces, weights] = computeCumFaces(Xtrain, XtrainNormalized, avgFace, index, U, numPC)
% returns a matrix (faces) whose rows contain an original image (first row), 
% average face (second row), and numPC additional rows created by adding 
% successive eigenfaces scaled by associated weights (also returned) for 
% this training image. Xtrain and XtrainNormalized contain the original
% and normalized training images, avgFace is the mean face image, index
% indicates which training example to use, U stores the eigenfaces and
% numPC is the desired number of eigenfaces to use

numPixels = size(Xtrain, 1);        % number of image pixels
faces = zeros(numPC+2, numPixels);  % matrix to be returned
faces(1,:) = Xtrain(:, index)';     % store original image in first row
faces(2,:) = avgFace';              % store average face in second row
% compute weights by projecting normalized image onto eigenfaces space
weights = U(:, 1:numPC)' * XtrainNormalized(:, index);  
newIm = avgFace;                    % initialize newIm to average face
% add numPC principal components (eigenfaces), scaled by associated weight 
for i = 1:numPC
    newIm = newIm + weights(i) * U(:,i);  % i-th weight * i-th eigenface
    faces(i+2, :) = newIm';         % add next composite to faces
end
    
end

