function [U, lambdas] = computeEigenfaces(XtrainNormalized)
% [U, lambdas] = computeEigenfaces(XtrainNormalized)
% given an input matrix containing the normalized training images (one
% image per column), returns eigenvectors stored in U and eigenvalues
% stored in lambdas

numTraining = size(XtrainNormalized, 2);    % number of training images
% compute covariance matrix
Q = XtrainNormalized' * XtrainNormalized / (numTraining - 1);
% V stores eigenvectors as columns, D is vector of corresponding eigenvalues
[V, D] = eig(Q, 'vector');
% sort eigenvectors by decreasing variance
V = fliplr(V);
lambdas = flipud(D);
% Pentland and Turk trick for computational efficiency
U = XtrainNormalized * V;   
% vectors have right directions but not unit norm, so make them unit norm 
cn = sqrt(sum(U.^2, 1));
U = bsxfun(@rdivide, U, cn);     

end

