function displayDataPCA(X, display_rows, display_cols, figWidth, titleStr)
% displayDataPCA(X, display_rows, display_cols, figWidth)
% opens a new figure window and displays a set of images that are stored 
% in the matrix X, in a grid of the specified number of rows and columns. 
% X is an m by (width*height) data matrix, where width is the number of
% columns in each image and height is the number of rows. Each image is 
% stored as a row of length width*height, and m is the number of images
% figWidth is the specified width of the figure window, titleStr is shown
% as a title and figure name

m = size(X, 1);     % number of images stored in matrix X

% dimensions of the images in the Yale faces database 
example_height = 243;
example_width = 210;

% setup blank display
pad = 1;            % padding between images
display_array = zeros(pad + display_rows * (example_height + pad), ...
                      pad + display_cols * (example_width + pad));

% copy each image example into a patch in the display array
curr_ex = 1;
for j = 1:display_rows
	for i = 1:display_cols
		if curr_ex > m 
			break; 
        end
		% get the maximum value in the patch
		max_val = max(abs(X(curr_ex, :)));
        % insert the image
		display_array(pad + (j-1) * (example_height + pad) + (1:example_height), ...
		              pad + (i-1) * (example_width + pad) + (1:example_width)) = ...
					reshape(X(curr_ex, :), example_height, example_width) / max_val;
		curr_ex = curr_ex + 1;
	end
	if curr_ex > m 
		break; 
	end
end

% display array of images
figure('Position', [100 100 figWidth 650])
colormap(gray);
imagesc(display_array);
axis off       % do not show axis
set(gcf, 'Name', titleStr);
title(titleStr, 'FontSize', 16);

end

