function [Xtrain, Xnorm, Xlight, Xexp, Xrot, mFace, lTrain, lTest, nTrain] = getFaceData()
% [Xtrain, Xnorm, Xlight, Xexp, Xrot, mFace, lTrain, lTest, nTrain] = getFaceData()
% loads training images into Xtrain (105 images) and Xnorm (subtracted
% average face) and loads test images into Xlight (left/right lighting),
% Xexp (happy/surprised expressions), Xrot (left/right 15 deg rotation)
% mFace is average face, lTrain stores ID labels for training set, lTest 
% stores ID labels for test sets, nTrain is number of training images

A = dir('yaleFacesNew/sub*');   % vector of directory structures
numPixels = 243 * 210;          % height x width for yaleFacesNew images
numSubjects = 15;
nTrain = 7 * numSubjects;       % use 7 poses for training set
Xtrain = zeros(numPixels, nTrain);  % stores training images
Xlight = zeros(numPixels, 2*numSubjects); % left/right lighting tests
Xexp = zeros(numPixels, 2*numSubjects);   % happy/surprised expression tests
Xrot = zeros(numPixels, 2*numSubjects);

% load training and test images into Xtrain, Xlight, Xexp
indexTrain = 1;     % column indices for the three matrices
indexLight = 1;
indexExp = 1;
for i = 1:numSubjects
    for j = 1:11                % loop through 11 poses in full dataset
        idx = 11*(i-1) + j;     % index for image file in A
        % load image file and convert to double
        dummy = im2double(imread(strcat('yaleFacesNew/', A(idx).name))); 
        % reshape image by concatenating columns into one long vector
        dummy = reshape(dummy, numPixels, 1);
        % store dummy in corresponding column of appropriate matrix
        if any(j == [1 2 5 6 8 9 11])       % poses for training
            Xtrain(:, indexTrain) = dummy;
            indexTrain = indexTrain + 1;
        elseif any(j == [4 7])              % left/right lighting tests
            Xlight(:, indexLight) = dummy;
            indexLight = indexLight + 1;
        else                            % happy/surprized expression tests
            Xexp(:, indexExp) = dummy;
            indexExp = indexExp + 1;
        end
    end
end

% load rotated test images into Xrot
A = dir('yaleFacesRot/sub*');   % directory of rotated images
indexRot = 1;                   % column index for Xrot matrix
for i = 1:numSubjects
    for j = 1:2
        idx = 2*(i-1) + j;     % index for image file in A
        % load image file and convert to double
        dummy = im2double(imread(strcat('yaleFacesRot/', A(idx).name))); 
        % reshape image by concatenating columns into one long vector
        dummy = reshape(dummy, numPixels, 1);
        % store dummy in column of Xrot matrix
        Xrot(:, indexRot) = dummy;
        indexRot = indexRot + 1;
    end
end

% calculate average face and normalize the training data
mFace = mean(Xtrain, 2);
Xnorm = bsxfun(@minus, Xtrain, mFace);

% create labels for training and test sets
labels = 1:numSubjects;
lTrain = repmat(labels, 7, 1);
lTrain = reshape(lTrain, 7*numSubjects, 1);
lTest = repmat(labels, 2, 1);
lTest = reshape(lTest, 2*numSubjects, 1);

end

