function accuracy = runTest(XtrainNormalized, Xtest, avgFace, U, numPC, ...
                            labelsTrain, labelsTest)
% accuracy = runTest(XtrainNormalized, Xtest, avgFace, U, numPC, ...
%                            labelsTrain, labelsTest)
% returns the accuracy of the PCA method for a set of test images
% XtrainNormalized stores normalized training images, which are projected
% onto the eigenfaces (eigenvectors, stored in the input matrix U) to obtain 
% the weights associated with each training image, Xtest stores the test 
% images that are normalized (using the input avgFace) and then projected 
% onto the eigenfaces, numPC specifies the number of eigenfaces to use,
% labelsTrain and labelsTest are the correct ID labels for the training and
% test images

numTest = size(Xtest, 2);                   % number of test images
numTraining = size(XtrainNormalized, 2);    % number of training images
% project normalized training images to the eigenfaces space
trainingFeatures = U(:, 1:numPC)' * XtrainNormalized;

% go over the full set of test images to classify each face

% project the mean subtracted test set to the eigenfaces space
testFeatures =  U(:, 1:numPC)' * bsxfun(@minus, Xtest, avgFace);

% vector for storing subject ID prediction 
pred = zeros(numTest, 1);

% loop over test set examples
for k = 1:numTest
    test_vec = testFeatures(:, k);       % choose corresponding example
    % compare weights to those of all the training cases
    score = arrayfun(@(p) norm(trainingFeatures(:,p) - test_vec), 1:numTraining);
    [~, hit]= min(score);       % find label associated with minimum score
    pred(k) = labelsTrain(hit);
end

% compute the accuracy in prediction of the subject IDs for the test set 
accuracy = 100 * sum(pred == labelsTest) / numTest;

end

